@@ -288,12 +288,13 @@ class SentryTrace:
 
     def __init__(self, thread, is_crashed):
         thread.switch()
+        self.thread = thread
         self.is_crashed = is_crashed
         self.lock_reasons = {}
         self.was_main_thread = False
         self.crashed = self.is_crashed # different from is_crashed (=input) this indicates if we stumbled over the kcrash handler
 
-    def load_solib(cramped):
+    def load_solib(thread, cramped): # NOTE: we pull thread into scope for its diagnostic value
         # Lazy load solibs. This is super complicated because the gdb CLI and API don't actually give us all the control.
         # Also loading new symbols resets the trace so we need to select-frames fairly aggressively.
 
@@ -306,23 +307,26 @@ class SentryTrace:
                 if not gdb.selected_frame().older():
                     break
 
-            # Increment in the beginning so we can continue early without having to worry that the index will be off
+            # Increment in the beginning so we can `continue` early without having to worry that the index will be off
             i = i + 1
 
             # Select the actual frame for loading
             gdb.execute(f'select-frame {i}')
             frame = gdb.selected_frame()
 
+            pc = frame.pc()
+
             # Determine the solib path
-            solib = gdb.current_progspace().solib_name(frame.pc())
+            solib = gdb.current_progspace().solib_name(pc)
             if solib in SentryTrace.loaded_solibs:
                 continue
+            image = None
             for core_image in core_images:
-                if int(core_image.address, 16) <= frame.pc() < (int(core_image.address, 16) + core_image.length):
+                if int(core_image.address, 16) <= pc < (int(core_image.address, 16) + core_image.length):
                     image = core_image
                     break
             if not solib and not image:
-                raise UnexpectedMappingException("No solib and no image found for frame!")
+                raise UnexpectedMappingException(f"No solib and no image found for frame #{i} on thread {thread}! You could try with debug symbols downloading enabled.")
             solib = solib or image.file
 
             if solib in SentryTrace.loaded_solibs:
@@ -341,6 +345,11 @@ class SentryTrace:
                 # (Re)load the symbols
                 gdb.execute(f'add-symbol-file {solib}')
 
+            sentry_sdk.add_breadcrumb(
+                category='debug',
+                level='debug',
+                message=f'Loaded solib {solib}',
+            )
             SentryTrace.loaded_solibs.append(solib)
 
         gdb.execute('select-frame 0')
@@ -352,7 +361,7 @@ class SentryTrace:
         spacious_memory = os.getenv('DRKONQI_MEMORY') == 'spacious'
         # In spacious mode we load all solibs by default and don't need to do anything extra. All other modes load on-demand.
         if cramped_memory or little_memory or some_memory:
-            SentryTrace.load_solib(cramped_memory)
+            SentryTrace.load_solib(self.thread, cramped_memory)
 
         frames = [ SentryFrame(frame) for frame in gdb.FrameIterator.FrameIterator(gdb.newest_frame()) ]
 
